@@ -9,8 +9,8 @@ import unittest
 # import requests
 # from mock import patch
 
-from domonic.html import *
-from domonic.CDN import *
+from domonic.html import script, link, img
+from domonic.CDN import CDN_JS, CDN_CSS, CDN_IMG
 
 
 class TestCase(unittest.TestCase):
